@@ -110,10 +110,13 @@ class LocalDBRequestAdapter():
 
     is_deleted = query_params.get('filter') == 'is_deleted'
     starred = query_params.get('filter') == 'starred'
+    unassigned = query_params.get('filter') == 'unassigned'
 
     requests = Request.where('is_deleted', is_deleted)
 
-    if scenario_id: 
+    if unassigned:
+      requests = requests.where('scenario_id', None)
+    elif scenario_id: 
       requests = requests.where('scenario_id', int(scenario_id))
       sort_order = query_params.get('sort_order') or 'asc' 
 
@@ -163,7 +166,8 @@ class LocalDBRequestAdapter():
     if uri.hostname:
       return base_model.where('host', uri.hostname).where('path', uri.path)
     else:
-      return base_model.where('path', 'like', f"%{query}%")
+      pattern = f"%{query}%"
+      return base_model.where('path', 'like', pattern).or_where('host', 'like', pattern)
 
   def __http_version(self, http_version: str):
     if not isinstance(http_version, str):
