@@ -1,3 +1,3 @@
-from .joined_request import JoinedRequest
+from .joined_request import REQUEST_DELIMITTER, JoinedRequest
 from .request_string import RequestString
 from .response_string import ResponseString
\ No newline at end of file
